@@ -1,6 +1,6 @@
-version_info = (1, 1, 0, 'final')
+version_info = (2, 0, 0, 'final')
 
-_specifier_ = {'alpha': 'a', 'beta': 'b', 'candidate': 'rc', 'final': ''}
+_specifier_ = {'alpha': 'a', 'beta': 'b', 'candidate': 'rc', 'final': '', 'dev': 'dev'}
 
 __version__ = '%s.%s.%s%s'%(version_info[0], version_info[1], version_info[2],
           '' if version_info[3]=='final' else _specifier_[version_info[3]]+str(version_info[4]))
@@ -11,4 +11,4 @@ __version__ = '%s.%s.%s%s'%(version_info[0], version_info[1], version_info[2],
 #
 # Update this value when attributes are added/removed from
 # the widget models, or if the serialized format changes.
-EXTENSION_SPEC_VERSION = '~1.1.0'
+EXTENSION_SPEC_VERSION = '^2.0.0'
