@@ -713,26 +713,6 @@ var ThreeModel = widgets.WidgetModel.extend({
         Object.assign(obj[key], value);
     },
 
-    convertUniformDictModelToThree: function(modelDict) {
-        if (modelDict === null) {
-            return null;
-        }
-        // Convert any strings to THREE.Color
-        // Just modify dict in-place, as it should serialize the same
-        Object.keys(modelDict).forEach(function(k) {
-            var value = modelDict[k].value;
-            if (value && (typeof value === 'string' || value instanceof String)) {
-                modelDict[k].value = new THREE.Color(value);
-            }
-        });
-        return modelDict;
-    },
-
-    convertUniformDictThreeToModel: function(threeDict) {
-        // No-op
-        return threeDict;
-    },
-
     // ThreeTypeArray
     convertThreeTypeArrayModelToThree: function(modelArr, propName) {
         if (!Array.isArray(modelArr)) {
@@ -783,21 +763,22 @@ var ThreeModel = widgets.WidgetModel.extend({
     },
 
     // ArrayBuffer
-    convertArrayBufferModelToThree: function(arr) {
-        if (arr === null) {
-            return null;
-        }
-        if (arr instanceof widgets.WidgetModel) {
-            return arr.get('array').data;
-        }
-        return arr.data;
+    convertArrayBufferModelToThree: function(ref, propName) {
+        var arr = dataserializers.getArray(ref);
+        return arr && arr.data;
     },
 
-    convertArrayBufferThreeToModel: function(arrBuffer) {
+    convertArrayBufferThreeToModel: function(arrBuffer, propName) {
         if (arrBuffer === null) {
             return null;
         }
-        // Never back-convert to a new widget
+        var current = this.get(propName);
+        var currentArray = dataserializers.getArray(current);
+        if (currentArray && (currentArray.data === arrBuffer)) {
+            // Unchanged, do nothing
+            return current;
+        }
+        // Never create a new widget, even if current is one
         return ndarray(arrBuffer);
     },
 
